"use strict";

exports.__esModule = true;
var _exportNames = {
  render: true,
  getElementStyles: true,
  testA11y: true,
  waitMs: true,
  useDefaultProviders: true,
  userEvent: true,
  axe: true
};
exports.getElementStyles = getElementStyles;
exports.waitMs = waitMs;
exports.useDefaultProviders = exports.testA11y = exports.render = void 0;

var _vueTheme = _interopRequireDefault(require("@chakra-ui/vue-theme"));

require("@testing-library/jest-dom");

require("@testing-library/jest-dom/extend-expect");

var vtl = _interopRequireWildcard(require("@testing-library/vue"));

Object.keys(vtl).forEach(function (key) {
  if (key === "default" || key === "__esModule") return;
  if (Object.prototype.hasOwnProperty.call(_exportNames, key)) return;
  if (key in exports && exports[key] === vtl[key]) return;
  exports[key] = vtl[key];
});

var _userEvent = _interopRequireDefault(require("@testing-library/user-event"));

exports.userEvent = _userEvent["default"];

var _vue2 = require("vue");

var _jestAxe = require("jest-axe");

exports.axe = _jestAxe.axe;

function _getRequireWildcardCache() { if (typeof WeakMap !== "function") return null; var cache = new WeakMap(); _getRequireWildcardCache = function _getRequireWildcardCache() { return cache; }; return cache; }

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { "default": obj }; } var cache = _getRequireWildcardCache(); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj["default"] = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

function asyncGeneratorStep(gen, resolve, reject, _next, _throw, key, arg) { try { var info = gen[key](arg); var value = info.value; } catch (error) { reject(error); return; } if (info.done) { resolve(value); } else { Promise.resolve(value).then(_next, _throw); } }

function _asyncToGenerator(fn) { return function () { var self = this, args = arguments; return new Promise(function (resolve, reject) { var gen = fn.apply(self, args); function _next(value) { asyncGeneratorStep(gen, resolve, reject, _next, _throw, "next", value); } function _throw(err) { asyncGeneratorStep(gen, resolve, reject, _next, _throw, "throw", err); } _next(undefined); }); }; }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

expect.extend(_jestAxe.toHaveNoViolations);

var useDefaultProviders = function useDefaultProviders() {
  (0, _vue2.provide)('$chakraTheme', _vueTheme["default"]);
  (0, _vue2.provide)('$chakraColorMode', 'light');
  (0, _vue2.provide)('$chakraIcons', {});
};

exports.useDefaultProviders = useDefaultProviders;

/** Render component instance */
var render = function render(component) {
  for (var _len = arguments.length, rest = new Array(_len > 1 ? _len - 1 : 0), _key = 1; _key < _len; _key++) {
    rest[_key - 1] = arguments[_key];
  }

  var utils = vtl.render.apply(vtl, [(0, _vue2.defineComponent)({
    name: 'ChakraUIVueTestContainer',
    setup: function setup(_, _ref) {
      var slots = _ref.slots;
      useDefaultProviders();
      return function () {
        return (0, _vue2.h)(component, slots);
      };
    }
  })].concat(rest));
  return _extends({}, utils, {
    asFragment: function asFragment(innerHTML) {
      if (innerHTML === void 0) {
        innerHTML = utils.container.innerHTML;
      }

      if (typeof document.createRange === 'function') {
        return document.createRange().createContextualFragment(innerHTML);
      }

      var template = document.createElement('template');
      template.innerHTML = innerHTML;
      return template.content;
    }
  });
};
/**
 * Wait for given ms
 *
 * @param {number} duration
 */


exports.render = render;

function waitMs(ms) {
  if (ms === void 0) {
    ms = 0;
  }

  return new Promise(function (resolve) {
    return setTimeout(resolve, ms);
  });
}
/**
 * Get styles from document.styleSheets
 *
 * @param {String} selector
 *
 * @example className usage
 *  getElementStyles('.anyClassName')
 *
 * @example Emotion Classname
 *  const [className1, className2] = [...screen.getByTestId('aspectRatioBox').classList]
 *  const styles = getElementStyles(`.${className1}`)
 *  const pseudoStyles = getElementStyles(`.${className2}:before`)
 */


function getElementStyles(selector) {
  var _selector = new RegExp(selector);

  var styles = '';
  var i;
  var j;
  var sel = _selector;

  for (i = 0; i < document.styleSheets.length; ++i) {
    for (j = 0; j < document.styleSheets[i].cssRules.length; ++j) {
      var styleRules = document.styleSheets[i].cssRules[j];

      if (sel.test(styleRules.selectorText)) {
        // let selectorText = document.styleSheets[i].cssRules[j].selectorText
        var cssText = styleRules.style.cssText;
        styles += cssText;
      }
    }
  }

  return styles;
}
/**
 * Validates against common a11y mistakes.
 *
 * Wrapper for jest-axe
 *
 * @example
 * ```ts
 * it('passes a11y test', async () => {
 *  await testA11Y(MyComponent, options);
 * });
 *
 * // sometimes we need to perform interactions first to render conditional UI
 * it('passes a11y test when open', async () => {
 *  const { container } = render(MyComponent, options);
 *
 *  fireEvent.click(screen.getByRole('button'));
 *
 *  await testA11Y(container, options);
 * });
 * ```
 */


var testA11y = /*#__PURE__*/function () {
  var _ref2 = _asyncToGenerator( /*#__PURE__*/regeneratorRuntime.mark(function _callee(ui, _temp) {
    var _ref3, axeOptions, options, container, results;

    return regeneratorRuntime.wrap(function _callee$(_context) {
      while (1) {
        switch (_context.prev = _context.next) {
          case 0:
            _ref3 = _temp === void 0 ? {} : _temp, axeOptions = _ref3.axeOptions, options = _objectWithoutPropertiesLoose(_ref3, ["axeOptions"]);
            container = vtl.render(ui, options).container;
            _context.next = 4;
            return (0, _jestAxe.axe)(container, axeOptions);

          case 4:
            results = _context.sent;
            expect(results).toHaveNoViolations();

          case 6:
          case "end":
            return _context.stop();
        }
      }
    }, _callee);
  }));

  return function testA11y(_x, _x2) {
    return _ref2.apply(this, arguments);
  };
}();

exports.testA11y = testA11y;
//# sourceMappingURL=render.js.map