function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

function asyncGeneratorStep(gen, resolve, reject, _next, _throw, key, arg) { try { var info = gen[key](arg); var value = info.value; } catch (error) { reject(error); return; } if (info.done) { resolve(value); } else { Promise.resolve(value).then(_next, _throw); } }

function _asyncToGenerator(fn) { return function () { var self = this, args = arguments; return new Promise(function (resolve, reject) { var gen = fn.apply(self, args); function _next(value) { asyncGeneratorStep(gen, resolve, reject, _next, _throw, "next", value); } function _throw(err) { asyncGeneratorStep(gen, resolve, reject, _next, _throw, "throw", err); } _next(undefined); }); }; }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

import theme from '@chakra-ui/vue-theme';
import '@testing-library/jest-dom';
import '@testing-library/jest-dom/extend-expect';
import * as vtl from '@testing-library/vue';
import userEvent from '@testing-library/user-event';
import { defineComponent, h, provide } from 'vue';
import { toHaveNoViolations, axe } from 'jest-axe';
expect.extend(toHaveNoViolations);

var useDefaultProviders = () => {
  provide('$chakraTheme', theme);
  provide('$chakraColorMode', 'light');
  provide('$chakraIcons', {});
};

/** Render component instance */
export var render = function render(component) {
  for (var _len = arguments.length, rest = new Array(_len > 1 ? _len - 1 : 0), _key = 1; _key < _len; _key++) {
    rest[_key - 1] = arguments[_key];
  }

  var utils = vtl.render(defineComponent({
    name: 'ChakraUIVueTestContainer',

    setup(_, _ref) {
      var {
        slots
      } = _ref;
      useDefaultProviders();
      return () => h(component, slots);
    }

  }), ...rest);
  return _extends({}, utils, {
    asFragment: function asFragment(innerHTML) {
      if (innerHTML === void 0) {
        innerHTML = utils.container.innerHTML;
      }

      if (typeof document.createRange === 'function') {
        return document.createRange().createContextualFragment(innerHTML);
      }

      var template = document.createElement('template');
      template.innerHTML = innerHTML;
      return template.content;
    }
  });
};
/**
 * Wait for given ms
 *
 * @param {number} duration
 */

function waitMs(ms) {
  if (ms === void 0) {
    ms = 0;
  }

  return new Promise(resolve => setTimeout(resolve, ms));
}
/**
 * Get styles from document.styleSheets
 *
 * @param {String} selector
 *
 * @example className usage
 *  getElementStyles('.anyClassName')
 *
 * @example Emotion Classname
 *  const [className1, className2] = [...screen.getByTestId('aspectRatioBox').classList]
 *  const styles = getElementStyles(`.${className1}`)
 *  const pseudoStyles = getElementStyles(`.${className2}:before`)
 */


export function getElementStyles(selector) {
  var _selector = new RegExp(selector);

  var styles = '';
  var i;
  var j;
  var sel = _selector;

  for (i = 0; i < document.styleSheets.length; ++i) {
    for (j = 0; j < document.styleSheets[i].cssRules.length; ++j) {
      var styleRules = document.styleSheets[i].cssRules[j];

      if (sel.test(styleRules.selectorText)) {
        // let selectorText = document.styleSheets[i].cssRules[j].selectorText
        var cssText = styleRules.style.cssText;
        styles += cssText;
      }
    }
  }

  return styles;
}
/**
 * Validates against common a11y mistakes.
 *
 * Wrapper for jest-axe
 *
 * @example
 * ```ts
 * it('passes a11y test', async () => {
 *  await testA11Y(MyComponent, options);
 * });
 *
 * // sometimes we need to perform interactions first to render conditional UI
 * it('passes a11y test when open', async () => {
 *  const { container } = render(MyComponent, options);
 *
 *  fireEvent.click(screen.getByRole('button'));
 *
 *  await testA11Y(container, options);
 * });
 * ```
 */

export var testA11y = /*#__PURE__*/function () {
  var _ref2 = _asyncToGenerator(function* (ui, _temp) {
    var _ref3 = _temp === void 0 ? {} : _temp,
        {
      axeOptions
    } = _ref3,
        options = _objectWithoutPropertiesLoose(_ref3, ["axeOptions"]);

    var container = vtl.render(ui, options).container;
    var results = yield axe(container, axeOptions);
    expect(results).toHaveNoViolations();
  });

  return function testA11y(_x, _x2) {
    return _ref2.apply(this, arguments);
  };
}();
export * from '@testing-library/vue';
export { userEvent, waitMs, useDefaultProviders };
export { axe };
//# sourceMappingURL=render.js.map